@@ -130,18 +130,86 @@ class Mesh:
         the insertion process. However, it can break the sorting order of the
         mesh segments in the list if used without care.
         """
+        if new_segment.validate_bnd(s0=new_segment.s0, s1=new_segment.s1):
+            if self.periodic and (new_segment.s0 < 0 or new_segment.s1 > self.upper_bnd):
+                self.make_mesh_segment_periodic(new_segment)
+            else:
+                new_segment, segment_valid = self.force_mesh_segment_in_mesh_domain(new_segment)
+                if segment_valid:
+                    index = self.get_mesh_segment_index(mesh_segment=new_segment, beg_index=beg_index)
+                    self.segment_list = numpy.insert(self.segment_list, index, new_segment)
+        else:
+            print("segment is invalid. s0 >= s1", new_segment.json_dict())
+
+    def force_mesh_segment_in_mesh_domain(self, segment):
+        """ force the non periodic mesh segments to be in the main mesh domain. """
+        segment_is_valid = True
+        if segment.s1 > self.upper_bnd and segment.s0 > self.upper_bnd:
+            print("segment is out of main mesh bounds. ", segment.json_dict())
+            segment_is_valid = False
+        elif segment.s0 < self.lower_bnd and segment.s1 < self.lower_bnd:
+            print("segment is out of main mesh bounds. ", segment.json_dict())
+            segment_is_valid = False
+        elif segment.s1 > self.upper_bnd >= segment.s0 >= self.lower_bnd:
+            print("segment s1 is out of main mesh bounds. Force s1 = upper_bnd ", segment.s1)
+            segment.s1 = self.upper_bnd
+        elif segment.s0 < self.lower_bnd <= segment.s1 <= self.upper_bnd:
+            print("segment s0 is out of main mesh bounds. Force s0 = lower_bnd ", segment.s0)
+            segment.s0 = self.lower_bnd
+        return segment, segment_is_valid
+
+    def make_mesh_segment_periodic(self, new_segment):
+        """ Force periodicity on mesh segments if periodic=True,
+        these cases occur when: new_segment.s0 < 0 or new_segment.s1 > 2 * numpy.pi"""
+        if 0 < new_segment.s0 < self.upper_bnd < new_segment.s1:
+            segment_1 = MeshSegment(s0=new_segment.s0, s1=self.upper_bnd, ds=new_segment.ds0,
+                                    var_ds_ratio=new_segment.var_ds_ratio)
+            segment_2 = MeshSegment(s0=0, s1=new_segment.s1 - self.upper_bnd, ds=new_segment.ds0,
+                                    var_ds_ratio=new_segment.var_ds_ratio)
+            index1 = self.get_mesh_segment_index(mesh_segment=segment_1)
+            index2 = self.get_mesh_segment_index(mesh_segment=segment_2)
+            self.segment_list = numpy.insert(self.segment_list, index1, segment_1)
+            self.segment_list = numpy.insert(self.segment_list, index2, segment_2)
+
+        elif self.upper_bnd < new_segment.s0 and self.upper_bnd < new_segment.s1:
+            new_segment.s0 = new_segment.s0 - self.upper_bnd
+            new_segment.s1 = new_segment.s1 - self.upper_bnd
+            index = self.get_mesh_segment_index(mesh_segment=new_segment)
+            self.segment_list = numpy.insert(self.segment_list, index, new_segment)
+
+        elif new_segment.s0 < 0 and new_segment.s1 < 0:
+            new_segment.s0 = new_segment.s0 + self.upper_bnd
+            new_segment.s1 = new_segment.s1 + self.upper_bnd
+            index = self.get_mesh_segment_index(mesh_segment=new_segment)
+            self.segment_list = numpy.insert(self.segment_list, index, new_segment)
+
+        elif new_segment.s0 < 0 and 0 < new_segment.s1 < self.upper_bnd:
+            segment_1 = MeshSegment(s0=0, s1=new_segment.s1, ds=new_segment.ds0, var_ds_ratio=new_segment.var_ds_ratio)
+            segment_2 = MeshSegment(s0=new_segment.s0 + self.upper_bnd, s1=self.upper_bnd, ds=new_segment.ds0,
+                                    var_ds_ratio=new_segment.var_ds_ratio)
+            index1 = self.get_mesh_segment_index(mesh_segment=segment_1)
+            index2 = self.get_mesh_segment_index(mesh_segment=segment_2)
+            self.segment_list = numpy.insert(self.segment_list, index1, segment_1)
+            self.segment_list = numpy.insert(self.segment_list, index2, segment_2)
+
+        elif new_segment.s0 <= 0 and new_segment.s1 >= self.upper_bnd:
+            new_segment.s0 = 0
+            new_segment.s1 = self.upper_bnd
+            index = self.get_mesh_segment_index(mesh_segment=new_segment)
+            self.segment_list = numpy.insert(self.segment_list, index, new_segment)
+
+    def get_mesh_segment_index(self, mesh_segment, beg_index=0):
+        """ return the index of the mesh segment. """
         for index in range(beg_index, len(self.segment_list)):
             segment = self.segment_list[index]
-            if new_segment.s0 < segment.s0:
+            if mesh_segment.s0 < segment.s0:
                 break
-            elif new_segment.s0 == segment.s0:
-                if new_segment.s1 > segment.s1:
+            elif mesh_segment.s0 == segment.s0:
+                if mesh_segment.s1 > segment.s1:
                     index += 1
                 break
         else:
             index = len(self.segment_list)
-        self.segment_list = numpy.insert(self.segment_list, index, new_segment)
-
         return index
 
     def remove_mesh_segment(self, index):
