@@ -27,6 +27,7 @@ from mesh_generator.ui.my_axes import My_Axes
 from mesh_generator.ui.mesh_num_points import get_num_points
 from mesh_generator.ui.scroll_bar import VerticalScrolledFrame
 from mesh_generator.ui.table_chart import TableChart
+
 import os
 
 
@@ -37,20 +38,27 @@ class MeshApp:
         root = tk.Tk()
         root.wm_title("MainApp")  # title of the window.
         root.config(background="white")  # background color of the window.
-        root.geometry("1825x640")  # window size.
-        #root.minsize(width=1825, height=640)  # minimum window size that the user can adjust.
+        width_screen_mm = root.winfo_screenmmwidth()
+        width_screen_pxl = root.winfo_screenwidth()
+        height_screen_mm = root.winfo_screenmmheight()
+        height_screen_pxl = root.winfo_screenheight()
 
+        for ii in range(3):
+            root.grid_columnconfigure(ii, weight=1)  # the text and entry frames column
+        for jj in range(3):
+            root.grid_rowconfigure(jj, weight=1)  # all frames row
         # assign the mesh results folder
         self.mesh_results_folder = save_mesh_file_path
 
         # frame with instructions on how to use gui includes step 1 and step 2.
         # (submitting the boxes and input respective ds.)
-        self.leftFrame = VerticalScrolledFrame(root, width=440, height=600, relief=tk.SUNKEN, background="gray92")
-        self.leftFrame.grid(row=0, column=0, sticky=tk.W)  # position of the frame on the main window
+        self.leftFrame = VerticalScrolledFrame(root, relief=tk.SUNKEN, width=width_screen_pxl/4,
+                                               height=height_screen_pxl/5)
+        self.leftFrame.grid(row=0, column=0, sticky=tk.NSEW,  rowspan=2)
 
         # label with step 1 instruction
-        tk.Label(self.leftFrame, text="Step 1: Draw a box, when box is finalized click submit box button.",
-                 font=7).grid(row=0, column=0, columnspan=5, sticky=tk.NW, pady=10)
+        tk.Label(self.leftFrame, text="Step 1: Draw a box, when box is finalized click submit box button.").\
+            grid(row=0, column=0, columnspan=5, sticky=tk.NW, pady=10)
 
         # save latest box button
         tk.Button(self.leftFrame, text='Save latest box', activeforeground='navy',
@@ -88,87 +96,86 @@ class MeshApp:
         tk.Button(self.leftFrame, text='Box Chart', command=self.box_chart).grid(row=6, column=1)
 
         # step 2- enter ds values
-        tk.Label(self.leftFrame, text="Step 2: After submitting each box indicate desired ds in textbox below.",
-                 font=6).grid(row=7, column=0, columnspan=7, sticky=tk.W, pady=10)
+        tk.Label(self.leftFrame, text="Step 2: After submitting each box indicate desired ds in textbox below.")\
+            .grid(row=7, column=0, columnspan=7, sticky=tk.W, pady=10)
         tk.Label(self.leftFrame, text="ds", relief=tk.RIDGE, bg='lightgray', bd=2). \
             grid(row=8, column=1, sticky=tk.NSEW)
         tk.Label(self.leftFrame, text="var_ds_ratio", relief=tk.RIDGE, bg='lightgray', bd=2). \
             grid(row=8, column=2, sticky=tk.NSEW, columnspan=2)
 
         # second frame: includes step 3, 4 and building a radial mesh manually.
-        self.rightFrame = VerticalScrolledFrame(root, width=465, height=600, borderwidth=2, relief=tk.SUNKEN,
-                                                background="gray92")
-        self.rightFrame.grid(row=0, column=2)
+        self.rightFrame = VerticalScrolledFrame(root, relief=tk.SUNKEN, width=width_screen_pxl/4,
+                                                height=height_screen_pxl/5) # width=465, height=600, borderwidth=2,
+        self.rightFrame.grid(row=0, column=2, rowspan=2, sticky=tk.NSEW)
 
         # step 3- enter BG ratio
-        tk.Label(self.rightFrame, text="Step 3: Input BG ratio:", font=7).grid(row=0, column=0, sticky=tk.W, pady=10)
+        tk.Label(self.rightFrame, text="Step 3: Input BG ratio:").grid(row=0, column=0, sticky=tk.W, pady=10)
         self.bg_ratio = tk.Entry(self.rightFrame, width=5)
         self.bg_ratio.insert(tk.END, '1.06')
         self.bg_ratio.grid(row=0, column=1, sticky=tk.W)
 
         # enter FG ratio
-        tk.Label(self.rightFrame, text="Input FG ratio:", font=7).grid(row=0, column=2, sticky=tk.E, pady=10,
-                                                                       columnspan=2)
+        tk.Label(self.rightFrame, text="Input FG ratio:").grid(row=0, column=2, sticky=tk.E, pady=10, columnspan=2)
         self.fg_ratio = tk.Entry(self.rightFrame, width=5)
         self.fg_ratio.insert(tk.END, '1.03')
         self.fg_ratio.grid(row=0, column=4, sticky=tk.W)
 
         # step 4- get total number of points in theta and phi
-        tk.Button(self.rightFrame, text='\u03B8 number of points', font=7, command=self.num_points_theta) \
+        tk.Button(self.rightFrame, text='\u03B8 number of points', command=self.num_points_theta) \
             .grid(row=2, column=0, columnspan=1, pady=10)
-        tk.Button(self.rightFrame, text='\u03C6 number of points', font=7, command=self.num_points_phi) \
+        tk.Button(self.rightFrame, text='\u03C6 number of points', command=self.num_points_phi) \
             .grid(row=3, column=0, columnspan=1, pady=10)
 
-        tk.Label(self.rightFrame, text="     ", font=7).grid(row=2, column=1, pady=10, sticky=tk.W)
-        tk.Label(self.rightFrame, text="     ", font=7).grid(row=3, column=1, pady=10, sticky=tk.W)
+        tk.Label(self.rightFrame, text="     ").grid(row=2, column=1, pady=10, sticky=tk.W)
+        tk.Label(self.rightFrame, text="     ").grid(row=3, column=1, pady=10, sticky=tk.W)
 
         # step 4- get plots of phi and theta mesh results
-        tk.Label(self.rightFrame, text="Step 4: Get mesh results", font=7).grid(row=1, column=0, sticky=tk.W,
+        tk.Label(self.rightFrame, text="Step 4: Get mesh results").grid(row=1, column=0, sticky=tk.W,
                                                                                 pady=10)
-        tk.Button(self.rightFrame, text='\u03B8 mesh results', font=7, command=self.get_theta_results). \
+        tk.Button(self.rightFrame, text='\u03B8 mesh results', command=self.get_theta_results). \
             grid(row=2, column=2, sticky=tk.W, columnspan=2, pady=10)
-        tk.Button(self.rightFrame, text='\u03C6 mesh results', font=7, command=self.get_phi_results). \
+        tk.Button(self.rightFrame, text='\u03C6 mesh results', command=self.get_phi_results). \
             grid(row=3, column=2, sticky=tk.W, columnspan=2, pady=10)
 
         # step 5- radial mesh table
-        tk.Label(self.rightFrame, text="Step 5: Input radial mesh segments", font=7).grid(row=4, column=0,
+        tk.Label(self.rightFrame, text="Step 5: Input radial mesh segments").grid(row=4, column=0,
                                                                                           columnspan=2, pady=10,
                                                                                           sticky=tk.W)
         # get radial total number of mesh points
-        tk.Button(self.rightFrame, text='r number of points', font=7, command=self.num_points_r). \
+        tk.Button(self.rightFrame, text='r number of points', command=self.num_points_r). \
             grid(row=5, column=0, columnspan=1, pady=10)
-        tk.Label(self.rightFrame, text="     ", font=7).grid(row=5, column=1, pady=10, sticky=tk.W)
+        tk.Label(self.rightFrame, text="     ").grid(row=5, column=1, pady=10, sticky=tk.W)
 
         # get radial mesh resulted plot
-        tk.Button(self.rightFrame, text='r mesh results', font=7, command=self.get_radial_results). \
+        tk.Button(self.rightFrame, text='r mesh results', command=self.get_radial_results). \
             grid(row=5, column=2, sticky=tk.W, columnspan=2, pady=10)
 
         # total number of points of all mesh (t x p x r):
-        tk.Label(self.rightFrame, text="Compute total number of points:", font=7).grid(row=6, column=0, pady=10,
+        tk.Label(self.rightFrame, text="Compute total number of points:").grid(row=6, column=0, pady=10,
                                                                                        sticky=tk.W, columnspan=2)
-        tk.Button(self.rightFrame, text='\u03B8 x \u03C6 x r', font=7, command=self.total_num_points). \
+        tk.Button(self.rightFrame, text='\u03B8 x \u03C6 x r', command=self.total_num_points). \
             grid(row=6, column=2, sticky=tk.NSEW, pady=10)
 
         # RADIAL_BG_TEXTBOX
-        tk.Label(self.rightFrame, text="Radial BG ratio:", font=7).grid(row=7, column=0, sticky=tk.E)
+        tk.Label(self.rightFrame, text="Radial BG ratio:").grid(row=7, column=0, sticky=tk.E)
         self.radial_bg_ratio = tk.Entry(self.rightFrame, width=5)
         self.radial_bg_ratio.insert(tk.END, '1.06')
         self.radial_bg_ratio.grid(row=7, column=1, sticky=tk.W)
 
         # RADIAL_FG_TEXTBOX
-        tk.Label(self.rightFrame, text="Radial FG ratio:", font=7).grid(row=7, column=2, sticky=tk.E, columnspan=2)
+        tk.Label(self.rightFrame, text="Radial FG ratio:").grid(row=7, column=2, sticky=tk.E, columnspan=2)
         self.radial_fg_ratio = tk.Entry(self.rightFrame, width=5)
         self.radial_fg_ratio.insert(tk.END, '1.03')
         self.radial_fg_ratio.grid(row=7, column=4, sticky=tk.W)
 
         # R0_TEXTBOX
-        tk.Label(self.rightFrame, text="rMin:", font=7).grid(row=8, column=0, sticky=tk.E)
+        tk.Label(self.rightFrame, text="rMin:").grid(row=8, column=0, sticky=tk.E)
         self.rMin = tk.Entry(self.rightFrame, width=5)
         self.rMin.insert(tk.END, '1')
         self.rMin.grid(row=8, column=1, sticky=tk.W)
 
         # R1_TEXTBOX
-        tk.Label(self.rightFrame, text="rMax:", font=7).grid(row=9, column=0, sticky=tk.E)
+        tk.Label(self.rightFrame, text="rMax:").grid(row=9, column=0, sticky=tk.E)
         self.rMax = tk.Entry(self.rightFrame, width=5)
         self.rMax.insert(tk.END, '2.5')
         self.rMax.grid(row=9, column=1, sticky=tk.W)
@@ -207,27 +214,24 @@ class MeshApp:
         mpl.projections.register_projection(My_Axes)
 
         # frame containing the canvas
-        self.midFrame = tk.Frame(root, width=300, height=200, background="white")
-        self.midFrame.grid(row=0, column=1, rowspan=1)
+        self.midFrame = tk.Frame(root, background="white")  # , width=300, height=200,
+        self.midFrame.grid(row=0, column=1, rowspan=2)
         # Make the canvas decently large.
-        self.fig = Figure(figsize=(9, 4.5), dpi=100)
-        self.fig.subplots_adjust(left=0.02, bottom=0.1, right=0.96, top=0.92, wspace=0, hspace=0)
+        self.fig = Figure(figsize=(width_screen_mm/(3*25.4), height_screen_mm/(3*25.4))) # figsize=(8, 4), dpi=100
+        #self.fig.subplots_adjust(left=0.02, bottom=0.1, right=0.96, top=0.92, wspace=0, hspace=0)
         self.ax = self.fig.add_subplot(111, projection="My_Axes")
         self.hdf_file_path = hdf_file_path
         cmin = self.setup_magnetogram_plot(self.fig, self.hdf_file_path)
 
         # save ui_session button.
-        self.bottomFrame = tk.Frame(root, width=1830, height=10)
-        self.bottomFrame.grid(row=1, column=0, columnspan=3)
-        tk.Label(self.bottomFrame, text="\t".expandtabs(195), font=7).grid(row=0, column=0, sticky=tk.NSEW)
-        tk.Button(self.bottomFrame, text="Save session", font=7, command=self.save_ui_session).grid(row=0, column=1)
-        tk.Label(self.bottomFrame, text="\t".expandtabs(25), font=7).grid(row=0, column=5, sticky=tk.NSEW)
-        tk.Label(self.bottomFrame, text="vmin/vmax:", font=7).grid(row=0, column=9)
+        self.bottomFrame = tk.Frame(root) # width=1830, height=10
+        self.bottomFrame.grid(row=2, column=1, columnspan=1)
+        tk.Button(self.bottomFrame, text="Save session", command=self.save_ui_session).grid(row=0, column=1)
+        tk.Label(self.bottomFrame, text="vmin/vmax:").grid(row=0, column=9)
         self.cmax_value = tk.Entry(self.bottomFrame, width=5)
         self.cmax_value.insert(tk.END, str(abs(cmin)))
         self.cmax_value.grid(row=0, column=10, sticky=tk.W)
-        tk.Button(self.bottomFrame, text="apply", font=7, command=self.apply_new_scale).grid(row=0, column=11)
-        tk.Label(self.bottomFrame, text="\t".expandtabs(195), font=7).grid(row=0, column=12, sticky=tk.NSEW)
+        tk.Button(self.bottomFrame, text="apply", command=self.apply_new_scale).grid(row=0, column=11)
 
         self.canvas = FigureCanvasTkAgg(self.fig, master=self.midFrame)
         self.canvas.draw()
@@ -403,7 +407,7 @@ class MeshApp:
             num_points_t = get_num_points(os.path.join(self.mesh_results_folder, "tmp_mesh_t.dat"))
         except:
             num_points_t = "n/a"
-        tk.Label(self.rightFrame, text=str(num_points_t), font=7).grid(row=2, column=1, sticky=tk.SW)
+        tk.Label(self.rightFrame, text=str(num_points_t)).grid(row=2, column=1, sticky=tk.SW)
         return num_points_t
 
     def num_points_phi(self):
@@ -416,7 +420,7 @@ class MeshApp:
             num_points_p = get_num_points(os.path.join(self.mesh_results_folder, "tmp_mesh_p.dat"))
         except:
             num_points_p = "n/a"
-        tk.Label(self.rightFrame, text=str(num_points_p), font=7).grid(row=3, column=1, sticky=tk.SW)
+        tk.Label(self.rightFrame, text=str(num_points_p)).grid(row=3, column=1, sticky=tk.SW)
         return num_points_p
 
     def num_points_r(self):
@@ -429,7 +433,7 @@ class MeshApp:
             num_points_r = get_num_points(os.path.join(self.mesh_results_folder, "tmp_mesh_r.dat"))
         except:
             num_points_r = "n/a"
-        tk.Label(self.rightFrame, text=str(num_points_r), font=7).grid(row=5, column=1, sticky=tk.SW)
+        tk.Label(self.rightFrame, text=str(num_points_r)).grid(row=5, column=1, sticky=tk.SW)
         return num_points_r
 
     def total_num_points(self):
@@ -441,7 +445,7 @@ class MeshApp:
             total_np = int(np_t) * int(np_p) * int(np_r)
         except:
             total_np = "n/a"
-        tk.Label(self.rightFrame, text=str('{:.2e}'.format(total_np)), font=6).grid(row=6, column=3, sticky=tk.W,
+        tk.Label(self.rightFrame, text=str('{:.2e}'.format(total_np))).grid(row=6, column=3, sticky=tk.W,
                                                                                     columnspan=2)
 
     def write_tmp_mas_files(self):
@@ -1028,13 +1032,12 @@ class MeshApp:
 
 if __name__ == "__main__":
     # Choose the files to read, point the base_path to where you put the MapPipeline folder
-    pipeline_example_folder = '/Users/opalissan/Downloads/MagnetogramExamples'
-    base_path = pipeline_example_folder + '/Oct2011'
-    hdf_file_path1 = base_path + '/br_example_2011_10_01_raw.hdf'
 
+    hdf_file_path1 = "/Users/opalissan/Downloads/MagnetogramExamples/Oct2011/br_example_2011_10_01_raw.hdf"
+    hdf_file_path2 = "/Users/opalissan/Desktop/br_caplan_shine_fill_pt.h5"
     # ui dictionary
     my_ui_session = MeshInfo(lower_bnd_t=0, upper_bnd_t=np.pi, lower_bnd_p=0, upper_bnd_p=2 * np.pi,
                              lower_bnd_r=0, upper_bnd_r=2.5)
 
-    app = MeshApp(hdf_file_path=hdf_file_path1, ui_session_data=my_ui_session, UseExistingInput=False,
-                  save_mesh_file_path="/Users/opalissan/desktop/mesh_folder")
+    app = MeshApp(hdf_file_path=hdf_file_path2, ui_session_data=my_ui_session, UseExistingInput=False,
+                  save_mesh_file_path="/Users/opalissan/Desktop/mesh_folder")
